data={
 "quaoar":'''Quaoar is a **possible dwarf planet** and a large trans-Neptunian object (TNO) located in the **Kuiper Belt**. It has an estimated diameter of about '1,110 km', making it one of the largest known TNOs. Quaoar takes approximately '288 Earth years' to complete one orbit around the Sun. Its surface is believed to be covered with 'methane, ethane, and water ice', giving it a reddish appearance. Unlike Pluto, Quaoar does not have a strong atmosphere. It has two known moons, 'Weywot' and a recently discovered smaller satellite. Quaoar is notable for having a **ring system**, which is unusual for an object of its size. Although it has not been officially classified as a **dwarf planet**, its size and shape suggest that it is likely to meet the criteria.'''   
}